#
# spec file for package rust
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 Luke Jones, luke.nukem.jones@gmail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global prev_rust 1.16.0
%global cargo_version 0.18.0
%global abi gnu
%ifarch s390x
%global _arch s390x
%endif
%ifarch armv7hl
%global _arch armv7
%global abi gnueabihf
%endif
%ifarch aarch64
%global _arch aarch64
%endif
%ifarch ppc64
%global _arch powerpc64
%endif
%ifarch ppc64le
%global _arch powerpc64le
%endif
%ifarch x86_64
%global _arch x86_64
%endif
%ifarch %{ix86}
%global _arch i586
%endif
%global rust_triple %{_arch}-unknown-linux-%{abi}
%global dl_url https://static.rust-lang.org/dist
%bcond_with bootstrap
Name:           rust
Version:        1.17.0
Release:        1.5
Summary:        A systems programming language
License:        MIT or Apache-2.0
Group:          Development/Languages/Other
Url:            http://www.rust-lang.org
Source0:        %{dl_url}/rustc-%{version}-src.tar.gz
Source1:        config.toml
Source100:      cargo-%{cargo_version}-x86_64-unknown-linux-gnu.tar.gz
Source101:      cargo-%{cargo_version}-i686-unknown-linux-gnu.tar.gz
Source102:      cargo-%{cargo_version}-aarch64-unknown-linux-gnu.tar.gz
Source103:      cargo-%{cargo_version}-armv7-unknown-linux-gnueabihf.tar.gz
Source104:      cargo-%{cargo_version}-powerpc64-unknown-linux-gnu.tar.gz
Source105:      cargo-%{cargo_version}-powerpc64le-unknown-linux-gnu.tar.gz
Source106:      cargo-%{cargo_version}-s390x-unknown-linux-gnu.tar.gz
# PATCH-FIX-OPENSUSE: Set DT_SONAME when building dylibs
Patch1:         add-soname.patch
BuildRequires:  ccache
BuildRequires:  chrpath
BuildRequires:  cmake
BuildRequires:  curl
BuildRequires:  gcc-c++
BuildRequires:  llvm-devel
BuildRequires:  ninja
BuildRequires:  procps
BuildRequires:  python
Recommends:     cargo
Recommends:     %{name}-doc
Recommends:     %{name}-std

Provides:       rust = %{version}
Conflicts:      otherproviders(rust)
Conflicts:      rustc-bootstrap

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Restrict the architectures as building rust relies on being initially
# bootstrapped before we can build the n+1 release
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 ppc64 ppc64le s390x

%if 0%{?suse_version}
BuildRequires:  fdupes
%endif

# There are no successful builds for less than TW or Leap 42.2, so bootstrap
# until such time that there is.
%if %{with rust_bootstrap} || (0%{?suse_version} < 1330 && 0%{?sle_version} <= 120100)
BuildRequires:  rust-std-bootstrap = %{prev_rust}
BuildRequires:  rustc-bootstrap = %{prev_rust}
%else
# if there is a package choice, use prefer version in prjconfig
BuildRequires:  rust <= %{version}
BuildRequires:  rust >= %{prev_rust}
BuildRequires:  rust-std <= %{version}
BuildRequires:  rust-std >= %{prev_rust}
%endif

%description
Rust is a systems programming language focused on three goals:
safety, speed, and concurrency. It maintains these goals without
having a garbage collector, making it a useful language for a
number of use cases other languages are not good at: embedding
in other languages, programs with specific space and time
requirements, and writing low-level code, like device drivers
and operating systems. It improves on current languages targeting
this space by having a number of compile-time safety checks
that produce no runtime overhead, while eliminating all
data races. Rust also aims to achieve "zero-cost abstractions",
even though some of these abstractions feel like those of a
high-level language. Even then, Rust still allows precise
control like a low-level language would.

%package -n rust-std
Summary:        Standard library for Rust
Group:          Development/Languages/Other
Provides:       rust-std = %{version}
Conflicts:      otherproviders(rust-std)

%description -n rust-std
This package includes the standard libraries for building
applications written in Rust.

%package -n rust-doc
Summary:        Rust documentation
Group:          Development/Languages/Other
Provides:       rust-doc = %{version}
Conflicts:      otherproviders(rust-doc)

%description -n rust-doc
Documentation for the Rust language.

%package -n rust-gdb
Summary:        Gdb integration for rust binaries
Group:          Development/Languages/Other
Supplements:    packageand(%{name}:gdb)
Provides:       rust-gdb = %{version}
Provides:       rustc:%{_bindir}/rust-gdb
Conflicts:      otherproviders(rust-gdb)

%description -n rust-gdb
This subpackage provides pretty printers and a wrapper script for
invoking gdb on rust binaries.

%prep
%ifarch x86_64
%setup -q -T -b 100 -n cargo-%{cargo_version}-%{_arch}-unknown-linux-%{abi}
%endif
%ifarch %ix86
%setup -q -T -b 101 -n cargo-%{cargo_version}-i686-unknown-linux-%{abi}
%endif
%ifarch aarch64
%setup -q -T -b 102 -n cargo-%{cargo_version}-%{_arch}-unknown-linux-%{abi}
%endif
%ifarch armv7hl
%setup -q -T -b 103 -n cargo-%{cargo_version}-%{_arch}-unknown-linux-%{abi}
%endif
%ifarch ppc64
%setup -q -T -b 104 -n cargo-%{cargo_version}-%{_arch}-unknown-linux-%{abi}
%endif
%ifarch ppc64le
%setup -q -T -b 105 -n cargo-%{cargo_version}-%{_arch}-unknown-linux-%{abi}
%endif
%ifarch s390x
%setup -q -T -b 106 -n cargo-%{cargo_version}-%{_arch}-unknown-linux-%{abi}
%endif

# The cargo binary is only used to build rust and is not shipped
# Using i686 for i586 seems to be okay for now but may cause issues in future
%ifarch %ix86
%global cargo_bin %{_builddir}/cargo-%{cargo_version}-i686-unknown-linux-%{abi}/cargo/bin/cargo
%else
%global cargo_bin %{_builddir}/cargo-%{cargo_version}-%{_arch}-unknown-linux-%{abi}/cargo/bin/cargo
%endif

%setup -q -n rustc-%{version}-src
%patch1 -p1
sed -e 's:<cargo-bin>:%{cargo_bin}:g' \
    -e 's:<rust-triple>:%{rust_triple}:g' \
	-e 's:<prefix>:%{_prefix}:g' \
    -e 's:<libdir>:%{_prefix}/lib:g' \
    -e 's:<mandir>:%{_mandir}:g' \
    -e 's:<docdir>:%{_docdir}/%{name}:g' \
    %{SOURCE1} > config.toml

%build
export CPPFLAGS="%{optflags}" # eliminate complain from RPMlint
./x.py build -v
./x.py doc -v

%install
sed -e 's:<cargo-bin>:%{cargo_bin}:g' \
    -e 's:<rust-triple>:%{rust_triple}:g' \
	-e 's:<prefix>:%{buildroot}%{_prefix}:g' \
    -e 's:<libdir>:%{buildroot}%{_prefix}/lib:g' \
    -e 's:<mandir>:%{buildroot}%{_mandir}:g' \
    -e 's:<docdir>:%{buildroot}%{_docdir}/%{name}:g' \
    %{SOURCE1} > config.toml
./x.py dist --install
# Fix any rpaths if needed
chrpath -d %{buildroot}%{_prefix}/lib/lib*.so

# Remove executable permission from HTML documentation
# to prevent RPMLINT errors.
chmod -R -x+X %{buildroot}%{_docdir}/%{name}/html

# Remove surplus files
rm %{buildroot}%{_prefix}/lib/rustlib/components
rm %{buildroot}%{_prefix}/lib/rustlib/manifest-rust*
rm %{buildroot}%{_prefix}/lib/rustlib/install.log
rm %{buildroot}%{_prefix}/lib/rustlib/uninstall.sh
rm %{buildroot}%{_prefix}/lib/rustlib/rust-installer-version
# Remove lockfile to avoid errors.
rm %{buildroot}%{_docdir}/%{name}/html/.lock

# The remaining shared libraries should be executable for debuginfo extraction.
find %{buildroot}/%{_prefix}/lib/ -type f -name '*.so' -exec chmod -v +x '{}' '+'

# extract bundled licenses for packaging - From fedora spec
cp src/rt/hoedown/LICENSE src/rt/hoedown/LICENSE-hoedown
sed -e '/*\//q' src/libbacktrace/backtrace.h \
  >src/libbacktrace/LICENSE-libbacktrace

# Remvove the license files from _docdir: make install put duplicates there
rm %{buildroot}%{_defaultdocdir}/%{name}/{COPYRIGHT,LICENSE-APACHE,LICENSE-MIT}

%if 0%{?suse_version}
%fdupes %{buildroot}%{_prefix}
%endif

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%license COPYRIGHT LICENSE-APACHE LICENSE-MIT
%license src/libbacktrace/LICENSE-libbacktrace
%license src/rt/hoedown/LICENSE-hoedown
%doc README.md
%{_bindir}/rustc
%{_bindir}/rustdoc
%{_bindir}/rust-lldb
%{_mandir}/man1/rustc.1*
%{_mandir}/man1/rustdoc.1*
%{_prefix}/lib/lib*.so
%exclude %{_docdir}/%{name}/html

%files -n rust-std
%defattr(-,root,root)
%dir %{_prefix}/lib/rustlib
%dir %{_prefix}/lib/rustlib/%{rust_triple}
%dir %{_prefix}/lib/rustlib/%{rust_triple}/lib
%{_prefix}/lib/rustlib/%{rust_triple}/lib/*.rlib
%{_prefix}/lib/rustlib/%{rust_triple}/lib/*.so 

%files -n rust-gdb
%defattr(-,root,root,-)
%{_bindir}/rust-gdb
%dir %{_prefix}/lib/rustlib
%dir %{_prefix}/lib/rustlib/etc
%{_prefix}/lib/rustlib/etc/debugger_pretty_printers_common.py
%{_prefix}/lib/rustlib/etc/gdb_load_rust_pretty_printers.py
%{_prefix}/lib/rustlib/etc/gdb_rust_pretty_printing.py
%{_prefix}/lib/rustlib/etc/lldb_rust_formatters.py

%files -n rust-doc
%defattr(-,root,root)
%license %{_docdir}/%{name}/html/FiraSans-LICENSE.txt
%license %{_docdir}/%{name}/html/Heuristica-LICENSE.txt
%license %{_docdir}/%{name}/html/LICENSE-APACHE.txt
%license %{_docdir}/%{name}/html/LICENSE-MIT.txt
%license %{_docdir}/%{name}/html/SourceCodePro-LICENSE.txt
%license %{_docdir}/%{name}/html/SourceSerifPro-LICENSE.txt
%dir %{_docdir}/%{name}
%dir %{_docdir}/%{name}/html
%doc %{_docdir}/%{name}/html/*

%changelog
* Wed May 10 2017 luke.nukem.jones@gmail.com
- Adjustment of rust version dependency to prevent inability to
  build in the adi rings.
* Sun Apr 30 2017 luke.nukem.jones@gmail.com
- Add the cargo binaries for each arch, used for building rust only
  these are not shipped, and don't factor in to the final product.
* Fri Apr 28 2017 luke.nukem.jones@gmail.com
- Revert restriction of x86 arch to i586 for the interim.
* Fri Apr 28 2017 luke.nukem.jones@gmail.com
- Update to 1.17.0
- Language updates
  * [The compiler's `dead_code` lint now accounts for type aliases][38051].
  * [Uninhabitable enums (those without any variants) no longer permit wildcard
    match patterns][38069]
  * [Clean up semantics of `self` in an import list][38313]
  * [`Self` may appear in `impl` headers][38920]
  * [`Self` may appear in struct expressions][39282]
- Compiler updates
  * [`rustc` now supports `--emit=metadata`, which causes rustc to emit
    a `.rmeta` file containing only crate metadata][38571]. This can be
    used by tools like the Rust Language Service to perform
    metadata-only builds.
  * [Levenshtein based typo suggestions now work in most places, while
    previously they worked only for fields and sometimes for local
    variables][38927]. Together with the overhaul of "no
    resolution"/"unexpected resolution" errors (#[38154]) they result in
    large and systematic improvement in resolution diagnostics.
  * [Fix `transmute::<T, U>` where `T` requires a bigger alignment than
    `U`][38670]
  * [rustc: use -Xlinker when specifying an rpath with ',' in it][38798]
  * [`rustc` no longer attempts to provide "consider using an explicit
    lifetime" suggestions][37057]. They were inaccurate.
- Stabilized APIs
  * [`VecDeque::truncate`]
  * [`VecDeque::resize`]
  * [`String::insert_str`]
  * [`Duration::checked_add`]
  * [`Duration::checked_sub`]
  * [`Duration::checked_div`]
  * [`Duration::checked_mul`]
  * [`str::replacen`]
  * [`str::repeat`]
  * [`SocketAddr::is_ipv4`]
  * [`SocketAddr::is_ipv6`]
  * [`IpAddr::is_ipv4`]
  * [`IpAddr::is_ipv6`]
  * [`Vec::dedup_by`]
  * [`Vec::dedup_by_key`]
  * [`Result::unwrap_or_default`]
  * [`<*const T>::wrapping_offset`]
  * [`<*mut T>::wrapping_offset`]
  * `CommandExt::creation_flags`
  * [`File::set_permissions`]
  * [`String::split_off`]
- Updates to libraries
  * [`[T]::binary_search` and `[T]::binary_search_by_key` now take
    their argument by `Borrow` parameter][37761]
  * [All public types in std implement `Debug`][38006]
  * [`IpAddr` implements `From<Ipv4Addr>` and `From<Ipv6Addr>`][38327]
  * [`Ipv6Addr` implements `From<[u16; 8]>`][38131]
  * [Ctrl-Z returns from `Stdin.read()` when reading from the console on
    Windows][38274]
  * [std: Fix partial writes in `LineWriter`][38062]
  * [std: Clamp max read/write sizes on Unix][38062]
  * [Use more specific panic message for `&str` slicing errors][38066]
  * [`TcpListener::set_only_v6` is deprecated][38304]. This
    functionality cannot be achieved in std currently.
  * [`writeln!`, like `println!`, now accepts a form with no string
    or formatting arguments, to just print a newline][38469]
  * [Implement `iter::Sum` and `iter::Product` for `Result`][38580]
  * [Reduce the size of static data in `std_unicode::tables`][38781]
  * [`char::EscapeDebug`, `EscapeDefault`, `EscapeUnicode`,
    `CaseMappingIter`, `ToLowercase`, `ToUppercase`, implement
    `Display`][38909]
  * [`Duration` implements `Sum`][38712]
  * [`String` implements `ToSocketAddrs`][39048]
- Misc
  * [`rustdoc` has a `--sysroot` argument that, like `rustc`, specifies
    the path to the Rust implementation][38589]
  * [The `armv7-linux-androideabi` target no longer enables NEON
    extensions, per Google's ABI guide][38413]
  * [The stock standard library can be compiled for Redox OS][38401]
  * [Rust has initial SPARC support][38726]. Tier 3. No builds
    available.
  * [Rust has experimental support for Nvidia PTX][38559]. Tier 3. No
    builds available.
  * [Fix backtraces on i686-pc-windows-gnu by disabling FPO][39379]
- Compatibility Notes
  * [Uninhabitable enums (those without any variants) no longer permit wildcard
    match patterns][38069]
  * In this release, references to uninhabited types can not be
    pattern-matched. This was accidentally allowed in 1.15.
  * [The compiler's `dead_code` lint now accounts for type aliases][38051].
  * [Ctrl-Z returns from `Stdin.read()` when reading from the console on
    Windows][38274]
  * [Clean up semantics of `self` in an import list][38313]
- Restrict x86 builds to i686 only.
- Revert restriction on previous rust versions used for building
* Sat Apr 22 2017 luke.nukem.jones@gmail.com
- Change x86 build target from i586 to i686
* Wed Mar 22 2017 luke.nukem.jones@gmail.com
- Switch .spec to use rust-build compilation system
- Update config.toml to reflect rust-build changes
- Strict versioning for compilation so rustc always use previous
  stable compiler
* Fri Mar 17 2017 luke.nukem.jones@gmail.com
- Update to 1.16.0
- Language updates
  * Lifetimes in statics and consts default to `'static`. [RFC 1623]
  * [The compiler's `dead_code` lint now accounts for type aliases][38051].
  * [Uninhabitable enums (those without any variants) no longer permit wildcard
    match patterns][38069]
  * [Clean up semantics of `self` in an import list][38313]
  * [`Self` may appear in `impl` headers][38920]
  * [`Self` may appear in struct expressions][39282]
- Compiler updates
  * [`rustc` now supports `--emit=metadata`, which causes rustc to emit
    a `.rmeta` file containing only crate metadata][38571]. This can be
    used by tools like the Rust Language Service to perform
    metadata-only builds.
  * [Levenshtein based typo suggestions now work in most places, while
    previously they worked only for fields and sometimes for local
    variables][38927]. Together with the overhaul of "no
    resolution"/"unexpected resolution" errors (#[38154]) they result in
    large and systematic improvement in resolution diagnostics.
  * [Fix `transmute::<T, U>` where `T` requires a bigger alignment than
    `U`][38670]
  * [rustc: use -Xlinker when specifying an rpath with ',' in it][38798]
  * [`rustc` no longer attempts to provide "consider using an explicit
    lifetime" suggestions][37057]. They were inaccurate.
- Stabilized APIs
  * [`VecDeque::truncate`]
  * [`VecDeque::resize`]
  * [`String::insert_str`]
  * [`Duration::checked_add`]
  * [`Duration::checked_sub`]
  * [`Duration::checked_div`]
  * [`Duration::checked_mul`]
  * [`str::replacen`]
  * [`str::repeat`]
  * [`SocketAddr::is_ipv4`]
  * [`SocketAddr::is_ipv6`]
  * [`IpAddr::is_ipv4`]
  * [`IpAddr::is_ipv6`]
  * [`Vec::dedup_by`]
  * [`Vec::dedup_by_key`]
  * [`Result::unwrap_or_default`]
  * [`<*const T>::wrapping_offset`]
  * [`<*mut T>::wrapping_offset`]
  * `CommandExt::creation_flags`
  * [`File::set_permissions`]
  * [`String::split_off`]
- Library updates
  * [`[T]::binary_search` and `[T]::binary_search_by_key` now take
    their argument by `Borrow` parameter][37761]
  * [All public types in std implement `Debug`][38006]
  * [`IpAddr` implements `From<Ipv4Addr>` and `From<Ipv6Addr>`][38327]
  * [`Ipv6Addr` implements `From<[u16; 8]>`][38131]
  * [Ctrl-Z returns from `Stdin.read()` when reading from the console on
    Windows][38274]
  * [std: Fix partial writes in `LineWriter`][38062]
  * [std: Clamp max read/write sizes on Unix][38062]
  * [Use more specific panic message for `&str` slicing errors][38066]
  * [`TcpListener::set_only_v6` is deprecated][38304]. This
    functionality cannot be achieved in std currently.
  * [`writeln!`, like `println!`, now accepts a form with no string
    or formatting arguments, to just print a newline][38469]
  * [Implement `iter::Sum` and `iter::Product` for `Result`][38580]
  * [Reduce the size of static data in `std_unicode::tables`][38781]
  * [`char::EscapeDebug`, `EscapeDefault`, `EscapeUnicode`,
    `CaseMappingIter`, `ToLowercase`, `ToUppercase`, implement
    `Display`][38909]
  * [`Duration` implements `Sum`][38712]
  * [`String` implements `ToSocketAddrs`][39048]
- Misc fixes
  * [`rustdoc` has a `--sysroot` argument that, like `rustc`, specifies
    the path to the Rust implementation][38589]
  * [The `armv7-linux-androideabi` target no longer enables NEON
    extensions, per Google's ABI guide][38413]
  * [The stock standard library can be compiled for Redox OS][38401]
  * [Rust has initial SPARC support][38726]. Tier 3. No builds
    available.
  * [Rust has experimental support for Nvidia PTX][38559]. Tier 3. No
    builds available.
  * [Fix backtraces on i686-pc-windows-gnu by disabling FPO][39379]
- Compatibility notes
  * [Uninhabitable enums (those without any variants) no longer permit wildcard
    match patterns][38069]
  * In this release, references to uninhabited types can not be
    pattern-matched. This was accidentally allowed in 1.15.
  * [The compiler's `dead_code` lint now accounts for type aliases][38051].
  * [Ctrl-Z returns from `Stdin.read()` when reading from the console on
    Windows][38274]
  * [Clean up semantics of `self` in an import list][38313]
* Mon Mar 13 2017 dimstar@opensuse.org
- Remove duplicate license files from _docdir: rpm 4.13 no longer
  implicitly packages those files and we catch them using %%license,
* Thu Feb 23 2017 bg@suse.com
- remove bootstrap for s390x as binaries are available in
  openSUSE:Factory:zSystems
* Wed Feb 15 2017 luke.nukem.jones@gmail.com
- Fixes to build for archs armv7, aarch64, ppc64, s390x
* Sat Feb 11 2017 luke.nukem.jones@gmail.com
- Update to 1.15.1
- Fix IntoIter::as_mut_slice's signature
* Mon Feb  6 2017 luke.nukem.jones@gmail.com
- Correct rust-triples use in spec.
* Mon Feb  6 2017 luke.nukem.jones@gmail.com
- Update to 1.15.0
- Language updates
  * Basic procedural macros allowing custom `#[derive]`, aka "macros 1.1", are
  stable. This allows popular code-generating crates like Serde and Diesel to
  work ergonomically. [RFC 1681].
  * [Tuple structs may be empty. Unary and empty tuple structs may be instantiated
  with curly braces][36868]. Part of [RFC 1506].
  * [A number of minor changes to name resolution have been activated][37127].
  They add up to more consistent semantics, allowing for future evolution of
  Rust macros. Specified in [RFC 1560], see its section on ["changes"] for
  details of what is different. The breaking changes here have been transitioned
  through the [`legacy_imports`] lint since 1.14, with no known regressions.
  * [In `macro_rules`, `path` fragments can now be parsed as type parameter
  bounds][38279]
  * [`?Sized` can be used in `where` clauses][37791]
  * [There is now a limit on the size of monomorphized types and it can be
  modified with the `#![type_size_limit]` crate attribute, similarly to
  the `#![recursion_limit]` attribute][37789]
- Compiler changes
  * [On Windows, the compiler will apply dllimport attributes when linking to
  extern functions][37973]. Additional attributes and flags can control which
  library kind is linked and its name. [RFC 1717].
  * [Rust-ABI symbols are no longer exported from cdylibs][38117]
  * [The `--test` flag works with procedural macro crates][38107]
  * [Fix `extern "aapcs" fn` ABI][37814]
  * [The `-C no-stack-check` flag is deprecated][37636]. It does nothing.
  * [The `format!` expander recognizes incorrect `printf` and shell-style
  formatting directives and suggests the correct format][37613].
  * [Only report one error for all unused imports in an import list][37456]
- Compiler performance
  * [Avoid unnecessary `mk_ty` calls in `Ty::super_fold_with`][37705]
  * [Avoid more unnecessary `mk_ty` calls in `Ty::super_fold_with`][37979]
  * [Don't clone in `UnificationTable::probe`][37848]
  * [Remove `scope_auxiliary` to cut RSS by 10%%][37764]
  * [Use small vectors in type walker][37760]
  * [Macro expansion performance was improved][37701]
  * [Change `HirVec<P<T>>` to `HirVec<T>` in `hir::Expr`][37642]
  * [Replace FNV with a faster hash function][37229]
- For full change list, please see
  https://raw.githubusercontent.com/rust-lang/rust/master/RELEASES.md
* Tue Jan 31 2017 luke.nukem.jones@gmail.com
- Adjust build so that aarch and ARM architectures use bootstrap for
  initial build
* Tue Jan 31 2017 luke.nukem.jones@gmail.com
- Fix provides/conflicts/obsoletes
* Fri Dec 23 2016 luke.nukem.jones@gmail.com
- Remove patch 0001-Fix-armv7-autodetection.patch
    + appears to have been fixed upstream.
- Building armv7hl arch with bootstrap binary since previously
  packaged versions haven't successfully built in the past
* Fri Dec 23 2016 luke.nukem.jones@gmail.com
- Update to version 1.14.0
    + Announcement: https://blog.rust-lang.org/2016/12/22/Rust-1.14.html
    + Details: https://github.com/rust-lang/rust/blob/master/RELEASES.md#version-1140-2016-12-22
- Release highlights:
    + support for RFC 1492. This small addition lets you use `..`
    in more places, for example when destructuring a struct or tuple
    + println!(), with no arguments, prints newline
    + Wrapping impls standard binary and unary operators on
    references, as well as the Sum and Product iterators, making
    references to these types easier to use
    + Implement From<Cow<str>> for String and From<Cow<[T]>> for
    Vec<T>. These implementations make sense, but were not yet added.
    + Expand .zip() specialization to .map() and .cloned() for
    improved performance.
    + Implement RefUnwindSafe for atomic types, as these types are
    “unwind safe,” though that wasn’t obvious at first.
    + Specialize Vec::extend to Vec::extend_from_slice for
    performance gains.
    + Don’t reuse HashMap random seeds. This helps to mitigate one
    type of DDoS attack.
    + The internal memory layout of HashMap is more cache-friendly,
    for significant improvements in some operations
    + Impl Add<{str, Cow<str>}> for Cow<str>. We already support Add
    for other string types, so not having it on Cow is inconsistent.
* Sun Dec 18 2016 luke.nukem.jones@gmail.com
- Update to 1.13.0
* Sun Dec 18 2016 luke.nukem.jones@gmail.com
- Add conflicts to help avoid situations where previous versions
  or rustc-bootstrap may be installed
* Sun Dec 18 2016 luke.nukem.jones@gmail.com
- Update to 1.12.1
- Remove patches:
    + 0003-Disable-embedding-timestamp-information.patch - fixed
    by upstream
    + 0002-Add-armv6l-autodetection.patch - no-longer viable
* Fri Dec 16 2016 luke.nukem.jones@gmail.com
- Revert from v1.13 to v1.11 in preparation for alternative
  packaging.
* Wed Nov  2 2016 matwey.kornilov@gmail.com
- Add 0001-Fix-armv7-autodetection.patch
- Add 0002-Add-armv6l-autodetection.patch
  * fix armv6 and armv7 builds
* Tue Sep 20 2016 kgronlund@suse.com
- Update to 1.11
  + Add support for cdylib crate types
- Remove merged patches:
  * 0001-Fix-misleading-intentation-errors-on-gcc-6.0.patch
  * 0002-Fix-GCC-6-misleading-indentation-error-in-hoedown.patch
- Set DT_SONAME when building dylibs
  * Add add-soname.patch
* Tue Sep  6 2016 kgronlund@suse.com
- Move to package named rust
* Thu Aug  4 2016 mvyskocil@opensuse.org
- Update to 1.10
    + -C panic=abort flag for rustc or equivalent in Cargo.toml
    + new crate type cdylib, embeded library for other languages
    + In addition, a number of performance improvements landed in
    the compiler, and so did a number of usability improvements
    across the documentation, rustdoc itself, and various error
    messages.
    + This is the first release, which is guaranteed to be built
    by previous stable release of rustc
- Packaging:
    + drop bootstrap mode and use rustc 1.9
    + move documentation to versioned directory
* Sun Jul 31 2016 jengelh@inai.de
- Use smp_mflags for parallel building. Avoid sh invocation for
  simple ldconfig calls. Drop archaic %%clean section.
  Drop filler words from summary.
* Tue Jul 26 2016 kgronlund@suse.com
- Rename source package to rustc-1_9 to conform to naming standards.
* Tue Jul 12 2016 mvyskocil@opensuse.org
- Rename source package to rustc-190 to avoid unecessary rebuilds
  of rustc packages on upgrade
* Wed Jul  6 2016 kgronlund@suse.com
- Move stage0 binaries into separate package
- Disable embedding timestamp information
- Add 0003-Disable-embedding-timestamp-information.patch
* Tue Jun 28 2016 kgronlund@suse.com
- Rename package to rustc-stable
- Add rpmlintrc
- Make bootstrapping conditional
* Mon Jun 27 2016 kgronlund@suse.com
- Fix misleading indentation errors on GCC 6.0
- Remove snap2.sh
- Add 0001-Fix-misleading-intentation-errors-on-gcc-6.0.patch
- Add 0002-Fix-GCC-6-misleading-indentation-error-in-hoedown.patch
* Mon May 30 2016 mvyskocil@opensuse.org
- Update to version 1.9.0
    + Stabilization of std::panic
    + Deprecation warnings, #[deprecated] attribute
    + Compile time improvements
    + Rolling out use of specialization
    + Library stabilizations
    About 80 library functions and methods are now stable in 1.
    + http://blog.rust-lang.org/2016/05/26/Rust-1.9.html
* Fri Apr 15 2016 mvyskocil@opensuse.org
- Update to version 1.8.0:
    + Various “operator equals” operators, such as += and -=, are now
    overloadable via various traits.
    + Empty struct declaration can contain cutly braces
    + New (non default) cargo based build system for rustc
    + About 20 library functions and methods are now stable in 1.8
* Fri Mar  4 2016 kgronlund@suse.com
- Update to version 1.7.0:
    + Many stabilized APIs
    + Improved library performance
    + BTreeSet and its iterators, Iter, IntoIter, and Range are covariant over their contained type.
    + LinkedList and its iterators, Iter and IntoIter are covariant over their contained type.
    + str::replace now accepts a Pattern, like other string searching methods.
    + Any is implemented for unsized types.
    + Hash is implemented for Duration.
    + Soundness fixes, may break code. See RFC 1214 for more information.
    + Several bugs in the compiler's visibility calculations were fixed.
    + Parsing "." as a float results in an error instead of 0.
    + Borrows of closure parameters may not outlive the closure.
* Wed Jan 20 2016 i@xuzhao.net
- Update to version 1.6.0:
    + Stabilization of libcore and other library functions
    + Crates.io disallows wildcards
* Fri Oct 30 2015 mvyskocil@opensuse.org
- Update to version 1.4.0:
    + Several changes have been made to fix type soundness and improve the
    behavior of associated types. See RFC 1214. Although we have mostly
    introduced these changes as warnings this release, to become errors next
    release, there are still some scenarios that will see immediate breakage.
    + The str::lines and BufRead::lines iterators treat \r\n as line breaks in
    addition to \n.
    + Loans of 'static lifetime extend to the end of a function.
    + str::parse no longer introduces avoidable rounding error when parsing
    floating point numbers. Together with earlier changes to float
    formatting/output, "round trips" like f.to_string().parse() now preserve
    the value of f exactly.  Additionally, leading plus signs are now accepted.
* Sat Oct 17 2015 mvyskocil@opensuse.org
- Split the gdb support to rust-gdb subpackage
* Fri Sep 18 2015 mvyskocil@opensuse.org
- Update to version 1.3.0:
    + API stabilization, including the new Duration API and
    enhancements to Error and Hash/Hasher.
    + The substring matcher now uses a more efficient algorithm.
    + There were improvements to zero filling that speed up
    Vec::resize and Read::read_to_end.
    + The implementation of Read::read_to_end has been specialized
    for stdin and File, resulting in additional speedups.
    + The PartialEq implementation on slices is now much faster.
- Packaging: renamed source package to rustc to match upstream
* Wed Aug 12 2015 mvyskocil@opensuse.org
- Update to version 1.2.0:
    + An across-the-board improvement to real-world compiler performance.
    Representative crates include hyper (compiles 1.16x faster), html5ever
    (1.62x faster), regex (1.32x faster) and rust-encoding (1.35x faster). You
    can explore some of this performance data at Nick Cameron’s preliminary
    tracking site, using dates 2015-05-15 to 2015-06-25.
    + Parallel codegen is now working, and produces a 33%% speedup when
    bootstrapping on a 4 core machine. Parallel codegen is particularly useful
    for debug builds, since it prevents some optimizations; but it can also be
    used with optimizations as an effective -O1 flag. It can be activated
    by passing -C codegen-units=N to rustc, where N is the desired number
    of threads.
* Mon Jul 27 2015 mvyskocil@opensuse.org
- Update to version 1.1.0:
  + The std::fs module has been expanded to expand the set of
    functionality exposed:
  * DirEntry now supports optimizations like file_type and
    metadata which don't incur a syscall on some platforms.
  * A symlink_metadata function has been added.
  * The fs::Metadata structure now lowers to its OS counterpart,
    providing access to all underlying information.
  + The compiler now contains extended explanations of many errors.
    When an error with an explanation occurs the compiler suggests
    using the --explain flag to read the explanation. Error
    explanations are also available online.
  + Thanks to multiple improvements to type checking, as well as other
    work, the time to bootstrap the compiler decreased by 32%%.
- drop tar_scm service and use source urls
* Fri May 15 2015 kgronlund@suse.com
- Update to version 1.0.0:
  + lint: deny transmuting from immutable to mutable, since it's undefined behavior
  + std: update select internals to not use mutable transmuting
  + std: Remove index notation on slice iterators
  + std: Destabilize io::BufStream
  + Make RwLock::try_write try to obtain a write lock
  + std: Remove addition on vectors for now
  + thread: right now you can't actually set those printers
  + Fix #24872, XSS in docs not found page.
  + Update AUTHORS.txt and RELEASES.md for 1.0
  + std: Mark `mem::forget` as a safe function
  + core: impl AsRef<[u8]> for str
  + collections: impl AsRef<[u8]> for String
  + collections: change bounds of SliceConcatExt implementations to use Borrow instead of AsRef
  + Fix invalid references due to the automated string substitution
  + dropck: must assume `Box<Trait + 'a>` has a destructor of interest.
* Thu May  7 2015 opensuse-packaging@opensuse.org
- Rename binary package to rust
- Add build for i586
- Only run fdupes on SUSE builds
- Changed version format
- Update to version 1.0.0~beta4+git.1430848988.f873dc5:
  + Introduce a `FreeRegionMap` data structure. (#22779)
  + Fix #20616
  + std: Fix inheriting standard handles on windows
  + Fix #24895.
  + Fix zero-normalization of the pos of a `MultiByteChar`.
  + lint for mixing `#[repr(C)]` with an impl of `Drop`.
  + Bump prerelease version to .4
  + Add downcasting to std::error::Error
* Wed May  6 2015 matwey.kornilov@gmail.com
- Format spec file
* Wed Apr 29 2015 opensuse-packaging@opensuse.org
- Update to version 1.0.0beta3+git.1429985089.5241bf9:
  + Update Windows caveats
  + Utilize if..let for get_mut doc-comment examples
  + Indicate keywords are code-like in Fuse::reset_fuse doc comment
  + doc: improve/fix 'let' FAQ
  + Fix broken links in the docs
  + Indicate None is code-like in doc comments
  + Fixed typo in hash_map::Entry documentation
  + Remove an unused import on windows
* Wed Apr 29 2015 kgronlund@suse.com
- Version 1.0.0-beta3.
